pub struct ConnectionTracker {
status_notification_tx: UnboundedSender<ConnectionStatus>,
has_marked_open: bool,
label: Arc<str>,
}Expand description
A per-connection tracker.
ActiveConnectionCounter creates a tracker instance for each active connection.
When these trackers are dropped, the counter gets notified.
Fields
status_notification_tx: UnboundedSender<ConnectionStatus>The channel used to send open connection status notifications on first response or closed connection notifications on drop.
has_marked_open: boolA flag indicating whether this connection tracker has sent a notification that the connection has been opened and that another notification should not be sent on drop.
label: Arc<str>The label for this connection counter, typically its type.
Implementations
Sourceimpl ConnectionTracker
impl ConnectionTracker
Sourcepub fn mark_open(&mut self)
pub fn mark_open(&mut self)
Sends a notification to the status notification channel to count the connection as open, and
marks this ConnectionTracker as having sent that open notification to avoid double-counting.
Sourcefn new(counter: &mut ActiveConnectionCounter) -> Self
fn new(counter: &mut ActiveConnectionCounter) -> Self
Create and return a new active connection tracker, and add 1 to counter.
All connection trackers share a label with their connection counter.
When the returned tracker is dropped, counter will be notified, and decreased by 1.